==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>打开wifi</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>关闭wifi</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>大写</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>小写</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>打开数字键盘</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>关闭数字键盘</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>打开触控板</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>关闭触控板</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>触摸板切换</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn切换</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>打开飞行模式</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>关闭飞行模式</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省电模式</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>性能模式</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>开启窗口特效</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>关闭窗口特效</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>打开窗口特效失败</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>麦克风已关</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>麦克风已开</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>打开wifi</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>关闭wifi</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>大写</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>小写</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>打开数字键盘</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>关闭数字键盘</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>打开触控板</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>关闭触控板</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>触摸板切换</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn切换</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>打开飞行模式</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>关闭飞行模式</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省电模式</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>性能模式</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>开启窗口特效</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>关闭窗口特效</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>打开窗口特效失败</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>麦克风已关</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>麦克风已开</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation>摄像头已开启</translation>
    </message>
    <message>
        <source>Camera off</source>
        <translation>摄像头已关闭</translation>
    </message>
</context>
</TS>
